@@ -1,4 +1,4 @@
-/* $Id: memobj-r0drv-linux.c 142111 2021-01-05 17:06:36Z paulson $ */
+/* $Id: memobj-r0drv-linux.c 142337 2021-01-21 19:35:49Z bird $ */
 /** @file
  * IPRT - Ring-0 Memory Objects, Linux.
  */
@@ -536,7 +536,7 @@ typedef const LNXAPPLYPGRANGE *PCLNXAPPLYPGRANGE;
  * @param   uAddr               The address to apply the new protection to.
  * @param   pvUser              The opaque user data.
  */
-static DECLCALLBACK(int) rtR0MemObjLinuxApplyPageRange(pte_t *pPte, unsigned long uAddr, void *pvUser)
+static int rtR0MemObjLinuxApplyPageRange(pte_t *pPte, unsigned long uAddr, void *pvUser)
 {
     PCLNXAPPLYPGRANGE pArgs = (PCLNXAPPLYPGRANGE)pvUser;
     PRTR0MEMOBJLNX pMemLnx = pArgs->pMemLnx;
